Struct googapis::google::cloud::resourcemanager::v3::SearchFoldersRequest[][src]

pub struct SearchFoldersRequest {
    pub page_size: i32,
    pub page_token: String,
    pub query: String,
}
The request message for searching folders.

Fields

page_size: i32

Optional. The maximum number of folders to return in the response. If unspecified, server picks an appropriate default.

page_token: String

Optional. A pagination token returned from a previous call to SearchFolders that indicates from where search should continue.

query: String

Optional. Search criteria used to select the folders to return. If no search criteria is specified then all accessible folders will be returned.

Query expressions can be used to restrict results based upon displayName, state and parent, where the operators = (:) NOT, AND and OR can be used along with the suffix wildcard symbol *.

The displayName field in a query expression should use escaped quotes for values that include whitespace to prevent unexpected behavior.

| Field                   | Description                            |
|-------------------------|----------------------------------------|
| displayName             | Filters by displayName.                |
| parent                  | Filters by parent (for example: folders/123). |
| state, lifecycleState   | Filters by state.                      |

Some example queries are: